@@ -7,7 +7,7 @@ class MVPoly(object) :
     Base (new-style) class for MVPoly. 
     """
 
-    def __init__(self, dtype = float) :
+    def __init__(self, dtype = np.double) :
         self._dtype = dtype 
 
     # subclasses are encouraged to overide the method
