@@ -1,5 +1,6 @@
 from mvpoly.cube import *
 import numpy as np
+import warnings
 import unittest
 
 class TestMVPolyCube(unittest.TestCase) :
@@ -416,22 +417,22 @@ class TestMVPolyCubeDiff(unittest.TestCase) :
 class TestMVPolyCubeInt(unittest.TestCase) :
 
     def test_int_1d(self) :
-        x, = MVPolyCube.monomials(1, dtype=float)
+        x, = MVPolyCube.monomials(1, dtype = np.double)
         p = 5*x**4 + 4*x
-        expected = (x**5 + 2*x**2).coef
-        obtained = p.int(1).coef
-        self.assertTrue((expected == obtained).all(),
+        expected = x**5 + 2*x**2
+        obtained = p.int(1)
+        self.assertTrue(expected == obtained,
                         "bad 1D indefinite integral \n%s\n%s" % \
-                            (repr(obtained), repr(expected)))
+                            (repr(obtained.coef), repr(expected.coef)))
 
     def test_int_2d(self) :
-        x, y = MVPolyCube.monomials(2, dtype=int)
+        x, y = MVPolyCube.monomials(2, dtype = np.double)
         p = 3*x**2 + 4*x*y + 3*y**2
         expected = (x**3 + 2*y*(x**2) + 3*x*y**2).coef 
         obtained = p.int(1, 0).coef
         self.assertTrue((expected == obtained).all(),
                         "bad indefinite integral (x) \n%s\n%s" % \
-                            (repr(obtained),repr(expected)))
+                            (repr(obtained), repr(expected)))
         expected = (3*y*x**2 + 2*x*y**2 + y**3).coef
         obtained = p.int(0, 1).coef
         self.assertTrue((expected == obtained).all(),
@@ -439,20 +440,31 @@ class TestMVPolyCubeInt(unittest.TestCase) :
                             (repr(obtained), repr(expected)))
 
     def test_int_dtype(self) :
-        for dt in [int, float] :
-            x, y = MVPolyCube.monomials(2, dtype=dt)
+        for dt in [np.float32, np.float64, np.complex] :
+            x, y = MVPolyCube.monomials(2, dtype=int)
             p = (x+y)**2
-            expected = float
-            obtained = p.int(1,1).dtype
+            q = p.int(1, 1, dtype=dt)
+            expected = dt
+            obtained = q.dtype
             self.assertTrue(expected == obtained, 
                             "bad datatype %s %s" % \
                                 (repr(obtained), repr(expected)))
 
+    def test_int_integer_warning(self) :
+        x, y = MVPolyCube.monomials(2, dtype=int)
+        p = 3*x + 4*y
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always')
+            p.int(1, 1)
+            self.assertTrue(len(w), "expected 1 warning, got %i" % (len(w)))
+            wcat = w[0].category
+            self.assertTrue(issubclass(wcat, RuntimeWarning),
+                            "expected RuntimeWarning, got %s" % (wcat))
 
 class TestMVPolyCubeIntDiff(unittest.TestCase) :
 
     def test_intdif_random(self) :
-        for dt in [int, float] :
+        for dt in [float, complex] :
             shp = (9, 10, 11)
             c = np.random.randint(low=-10, high=10, size=shp)
             p = MVPolyCube(c, dtype=dt)
